==> patch-2.2.26.zip: app/language/en/user.php <==
<?php

return array(

    // Index method Language
    'indexPageName' => 'User',
    'profilePage' => 'User Account Details',
    'listOfUsers' => 'List of Users',
    'device' => 'Device',
    'create' => 'Create',
    'devices' => 'Devices',
    'policy_info' => 'Policy Information',
    'createUserGroup' => 'Create User Group',
    'manageUserGroup' => 'Manage User Group',
    'usersBulkBlockDelete' => 'Delete or Block users in bulk',

    // Common For all Methods
    'profileDisplay' => 'Account Details',
    'myDevices' => 'My Devices',
    'deletedAGroup' => 'User Group deleted successfully',
    'passwordChanged' => 'User Password updated successfully',
    'userSavedSuccess' => 'User Details updated successfully',
    '421'       	=> 'Authentication token has <b>expired</b>',
    '447'       	=> 'Changes were not saved.  The User is under Legal hold. Please contact your Administrator.',
    '409'       	=> 'User already exists',
    '442'       	=> 'The email address is not a part of the Organization\'s Active Directory',
    '448'       	=> 'The selected <b>User</b> is the owner of a Mini-Cloud.  Please change ownership of the Mini-Cloud to an alternate user and try the deletion again.',
    '412'       	=> 'This email address already exists',
    '417'       	=> '<b>User Limit</b> <b>exceeded.</b>',
    '403'       	=> '<b>Backup User Limit</b> <b>exceeded.</b>',
	'500'       	=> 'Details couldn\'t be saved because the Server did not respond or is unreachable.  Please try again after a while.  If the failure persists, you may need to contact your Administrator for assistance.',
	'0'         	=> '<b>The Server is unreachable</b>. Please try again after some time.  If the failure persists, you may need to contact your Administrator for assistance.',
	'default'   	=> 'We\'re sorry, but something went <b>wrong</b>.  Please try again later.  If the failure persists, please contact your Administrator for assistance',
	'noData'    	=> 'Couldn\'t save the data because of errors in one or more fields, Please check and try submitting again',
    'cannotBlock'   => 'You cannot block <b>yourself</b>.  Please contact your Administrator for assistance.',
    'cannotDelete'  => 'You cannot delete <b>yourself</b>.   Please contact your Administrator for assistance.',
    'userBlocked'   => ' has been blocked successfully.',
    'userUnBlocked' => ' has been un-blocked successfully.',
    'userDeleted'   => 'The selected user has been deleted successfully.',
    'deletedMultipleUsers'      => 'Selected users deleted successfully.',
    'blockedMultipleUsers'      => 'Selected users blocked successfully.',
    'unBlockedMultipleUsers'    => 'Selected users un-blocked successfully.',
    'added_inclusion_folder'   		=> 'Folder <b>added</b> for inclusion.',
    'removed_inclusion_folder'   	=> 'Folder <b>removed</b>  successfully.',
    'added_exclusion_folder'   		=> 'Folder <b>added</b>  for exclusion.',
    'removed_exclusion_folder'   	=> 'Folder <b>removed</b> successfully.'
);

==> patch-2.5.3.18_3.zip: app/language/en/user.php <==
<?php

return array(

    // Index method Language
    'indexPageName' => 'User',
    'profilePage' => 'User Account Details',
    'listOfUsers' => 'List of Users',
    'device' => 'Device',
    'create' => 'Create',
    'devices' => 'Devices',
    'policy_info' => 'Policy Information',
    'createUserGroup' => 'Create User Group',
    'manageUserGroup' => 'Manage User Group',
    'usersBulkBlockDelete' => 'Delete or Block users in bulk',

    // Common For all Methods
    'profileDisplay' => 'User Account Details',
    'myDevices' => 'My Devices',
    'deletedAGroup' => 'User Group deleted successfully',
    'passwordChanged' => 'User Password updated successfully',
    'userSavedSuccess' => 'User Details updated successfully',
    '421'       	=> 'Authentication token has <b>expired</b>',
    '447'       	=> 'Changes were not saved.  The User is under Legal hold. Please contact your Administrator.',
    '409'       	=> 'User already exists',
    '442'       	=> 'The email address is not a part of the Organization\'s Active Directory',
    '448'       	=> 'The selected <b>User</b> is the owner of a Mini-Cloud.  Please change ownership of the Mini-Cloud to an alternate user and try the deletion again.',
    '412'       	=> 'Email address already in use',
    '417'       	=> '<b>User Limit</b> <b>exceeded.</b>',
    '403'       	=> '<b>Backup User Limit</b> <b>exceeded.</b>',
    '428'               => '<b>Office 365 for Backup User Limit</b> <b>exceeded.</b>',
	'500'       	=> 'Details couldn\'t be saved because the Server did not respond or is unreachable.  Please try again after a while.  If the failure persists, you may need to contact your Administrator for assistance.',
	'0'         	=> '<b>The Server is unreachable</b>. Please try again after some time.  If the failure persists, you may need to contact your Administrator for assistance.',
	'default'   	=> 'We\'re sorry, but something went <b>wrong</b>.  Please try again later.  If the failure persists, please contact your Administrator for assistance',
	'noData'    	=> 'Couldn\'t save the data because of errors in one or more fields, Please check and try submitting again',
    'cannotBlock'   => 'You cannot block <b>yourself</b>.  Please contact your Administrator for assistance.',
    'cannotDelete'  => 'You cannot delete <b>yourself</b>.   Please contact your Administrator for assistance.',
    'userBlocked'   => ' has been blocked successfully.',
    'userUnBlocked' => ' has been un-blocked successfully.',
    'userDeleted'   => 'The selected user has been deleted successfully.',
    'deletedMultipleUsers'      => 'Selected users deleted successfully.',
    'blockedMultipleUsers'      => 'Selected users blocked successfully.',
    'unBlockedMultipleUsers'    => 'Selected users un-blocked successfully.',
    'added_inclusion_folder'   		=> 'Folder <b>added</b> for inclusion.',
    'removed_inclusion_folder'   	=> 'Folder <b>removed</b>  successfully.',
    'added_exclusion_folder'   		=> 'Folder <b>added</b>  for exclusion.',
    'removed_exclusion_folder'   	=> 'Folder <b>removed</b> successfully.'
);
